/* This file was generated by syncqt. */
#ifndef QT_QTWAYLANDCOMPOSITOR_VERSION_H
#define QT_QTWAYLANDCOMPOSITOR_VERSION_H

#define QTWAYLANDCOMPOSITOR_VERSION_STR "5.15.4"

#define QTWAYLANDCOMPOSITOR_VERSION 0x050F04

#endif // QT_QTWAYLANDCOMPOSITOR_VERSION_H
